@@ -8,9 +8,16 @@ ANTONYMS = 'ants'
 INFLECTIONS = 'infs'
 EXAMPLE_SENTENCES = 'exst'
 AUDIO = 'aud'
+RAW_DATA = 'raw'
+SUPPLEMENTAL = 'supp'
+WORD_FREQ = 'freq'
+LINKS = 'link'
 
 # Japanese specific
 PITCH_ACCENT = 'acnt'
 READING = 'read'
 WRITINGS = 'writ'
-DETAILED_READING = 'rubi'
\ No newline at end of file
+DETAILED_READING = 'rubi'
+
+# English from Japanese specific
+KATAKANA = 'kana'
